@@ -12,13 +12,13 @@
 #
 #   This library is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License
-#   as published by the Free Software Foundation; either version 2
+#   as published by the Free Software Foundation; either version 3
 #   of the License, or (at your option) any later version.
 #   
 #   You should have received a copy of the GNU General Public
-#   License along with this library; see the file COPYING.LIB.
+#   License along with this library; see the file COPYING.
 #   If not, write to the Free Software Foundation,
-#   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 # Nothing to clean right now
 case "$1" in
@@ -31,11 +31,6 @@ case "$1" in
 	echo freebsd
 	exit 0
 	;;
-    # Remove version number for NetBSD ELF targets
-    netbsdelf* | netbsd1.6* | netbsd2*)
-	echo netbsdelf
-	exit 0
-	;;
     # Remove version number for Darwin
     darwin7*)
         echo darwin7
